==> haskell-monoid-subclasses-1.2.5.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monoid-subclasses.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monoid-subclasses
version:              1.2.5.1
visibility:           public
id:                   monoid-subclasses-1.2.5.1-D5e9kjgpXYG1KMhkyd8eZi
key:                  monoid-subclasses-1.2.5.1-D5e9kjgpXYG1KMhkyd8eZi
license:              BSD-3-Clause
copyright:            (c) 2013-2024 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/monoid-subclasses/
synopsis:             Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.

category:             Data, Algebra, Text
abi:                  65c73c8363a00c06cfdb2216532f3ff7
exposed:              True
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial Data.Monoid.GCD
    Data.Monoid.Instances.ByteString.UTF8
    Data.Monoid.Instances.CharVector Data.Monoid.Instances.Concat
    Data.Monoid.Instances.Measured Data.Monoid.Instances.Positioned
    Data.Monoid.Instances.PrefixMemory Data.Monoid.Instances.Stateful
    Data.Monoid.LCM Data.Monoid.Monus Data.Monoid.Null
    Data.Monoid.Textual Data.Semigroup.Cancellative
    Data.Semigroup.Factorial

import-dirs:          /usr/lib/ghc-9.2.8/site-local/monoid-subclasses-1.2.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monoid-subclasses-1.2.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monoid-subclasses
hs-libraries:         HSmonoid-subclasses-1.2.5.1-D5e9kjgpXYG1KMhkyd8eZi
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    commutative-semigroups-0.2.0.1-EH8LNaj5YwqAbhqQrh5UPi
    containers-0.6.5.1 primes-0.2.1.0-4FlmqGEB4JCDXui124fQpB
    text-1.2.5.0 vector-0.13.1.0-Il4qKxVtRccCcBZCzPMWy6

haddock-interfaces:
    /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock

haddock-html:         /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monoid-subclasses-1.2.5.1-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monoid-subclasses.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monoid-subclasses
version:              1.2.5.1
visibility:           public
id:                   monoid-subclasses-1.2.5.1-GBO2MQ0mq6RGXcxQnx0nqg
key:                  monoid-subclasses-1.2.5.1-GBO2MQ0mq6RGXcxQnx0nqg
license:              BSD-3-Clause
copyright:            (c) 2013-2024 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/monoid-subclasses/
synopsis:             Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.

category:             Data, Algebra, Text
abi:                  ad2e211e43e45d48e9ccc856e1010459
exposed:              True
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial Data.Monoid.GCD
    Data.Monoid.Instances.ByteString.UTF8
    Data.Monoid.Instances.CharVector Data.Monoid.Instances.Concat
    Data.Monoid.Instances.Measured Data.Monoid.Instances.Positioned
    Data.Monoid.Instances.PrefixMemory Data.Monoid.Instances.Stateful
    Data.Monoid.LCM Data.Monoid.Monus Data.Monoid.Null
    Data.Monoid.Textual Data.Semigroup.Cancellative
    Data.Semigroup.Factorial

import-dirs:          /usr/lib/ghc-9.2.8/site-local/monoid-subclasses-1.2.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monoid-subclasses-1.2.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monoid-subclasses
hs-libraries:         HSmonoid-subclasses-1.2.5.1-GBO2MQ0mq6RGXcxQnx0nqg
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    commutative-semigroups-0.2.0.1-EH8LNaj5YwqAbhqQrh5UPi
    containers-0.6.5.1 primes-0.2.1.0-4FlmqGEB4JCDXui124fQpB
    text-1.2.5.0 vector-0.13.1.0-1cpgbj3eXUqGZ3uVszXgJ9

haddock-interfaces:
    /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock

haddock-html:         /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
